//
//  ViewController.swift
//  RK-Setup-Git
//
//  Created by Gerardo Marx Chávez Campos on 10/10/24.
//

import UIKit
import ResearchKit
import ResearchKitUI


class ViewController: UIViewController {
    
    @IBOutlet weak var startTapped: UIButton!
    
    @IBAction func startSurveyTapped(_ sender: Any) {
        presentHeightSurvey()
    }
    
    override func viewDidLoad() {
        super.viewDidLoad()
        // Do any additional setup after loading the view.
        startTapped.setTitle("Start Survey", for: .normal)
    }
    
    func presentHeightSurvey() {
        let taskViewController = ORKTaskViewController(task: SurveyTaskProvider.createHeightFormTask(), taskRun: nil)
        taskViewController.delegate = self
        present(taskViewController, animated: true, completion: nil)
    }
}

// Extesions can be in other file:

extension ViewController: ORKTaskViewControllerDelegate {
    func taskViewController(_ taskViewController: ORKTaskViewController, didFinishWith reason: ORKTaskFinishReason, error: (any Error)?) {
        
        // Handle the completion of the task and dismiss the view controller
        taskViewController.dismiss(animated: true, completion: nil)
        
        //handle error
        guard reason == .completed else {
            if let error = error {
                print("The task was not completed: \(error.localizedDescription)")
            }
            return
        }
        
        // processing results:
        if let results = taskViewController.result.results as? [ORKStepResult] {
            processSurveyResults(results)
        }
    }
    
    private func processSurveyResults(_ results: [ORKStepResult]) {
        // here
        for stepResults in results {
            for result in stepResults.results! {
                if let questionResult = result as? ORKQuestionResult {
                    print("Question ID: \(questionResult.identifier)")
                    processQuestionResult(questionResult)
                }
            }
        }
    }
    
    
    private func processQuestionResult(_ result: ORKQuestionResult) {
        if let heightResult = result as? ORKNumericQuestionResult, result.identifier == "heightQuestionFormItem1" {
            if let heigth = heightResult.numericAnswer {
                print("User's heigth is: \(heigth) cm")
            }
        }
    }
    
}
